@@ -257,7 +257,7 @@ def build_calculator(settings, constraints=list()):
         if "multiplicity" in settings:
             assert isinstance(settings["multiplicity"], int), "Calculator `multiplicity` must be an integer."
             assert settings["multiplicity"] > 0, "Calculator `multiplicity` must be positive."
-            charge = settings["multiplicity"]
+            multiplicity = settings["multiplicity"]
 
         gfn = 2
         if "gfn" in settings:
@@ -275,7 +275,7 @@ def build_calculator(settings, constraints=list()):
             assert isinstance(settings["xcontrol"], str), "Calculator `xcontrol` must be a string."
             xcontrol = settings["xcontrol"]
 
-        return presto.calculators.XTBCalculator(charge=charge, multiplicity=multiplicity, gfn=gfn, parallel=parallel, constraints=constraints, xcontrol=xcontrol)
+        return presto.calculators.XTBCalculator(charge=charge, multiplicity=multiplicity, gfn=gfn, parallel=parallel, constraints=constraints, xcontrol_path=xcontrol)
 
     else:
         raise ValueError(f"Unknown integrator type {settings['type']}! Allowed options are `oniom`, `xtb`, or `gaussian`.")
